@@ -1,6 +1,6 @@
 package Perl::Critic::Policy::logicLAB::RequireSheBang;
 
-# $Id: RequireSheBang.pm 7686 2011-05-16 20:24:20Z jonasbn $
+# $Id: RequireSheBang.pm 7701 2011-06-06 19:26:34Z jonasbn $
 
 use strict;
 use warnings;
@@ -8,7 +8,7 @@ use base 'Perl::Critic::Policy';
 use Perl::Critic::Utils qw{ $SEVERITY_MEDIUM :booleans };
 use List::MoreUtils qw(none);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 Readonly::Scalar my $EXPL => q{she-bang line should adhere to requirement};
 
@@ -27,13 +27,15 @@ sub applies_to {
 sub violates {
     my ( $self, $elem ) = @_;
 
+
     my ( $shebang, $cli ) = $elem =~ m{
             \A  #beginning of string
             (\#!) #actual she-bang
             ([/\-\w ]+) #the path and possible flags, note the space character
+            (?:\Z)? #optional indication of end of line to assist above capture
     }xsm;
 
-    if ( $shebang && none { ($elem) eq $_ } @{ $self->{_formats} } ) {
+    if ( $shebang && none { ($shebang.$cli) eq $_ } @{ $self->{_formats} } ) {
         return $self->violation(
             q{she-bang line not conforming with requirement},
             $EXPL, $elem );
